@@ -10,7 +10,7 @@
 from pathlib import Path
 
 # Local folder libraries
-from .about import get_pypi_slogan
+from .about import get_short_slogan
 
 THIS_DIR = Path(__file__).parent
 REPO_ROOT = THIS_DIR.parent.resolve()
@@ -26,5 +26,5 @@ TSFPGA_EXAMPLE_MODULES = TSFPGA_EXAMPLES / "modules"
 # Default encoding when opening files
 DEFAULT_FILE_ENCODING = "utf-8"
 
-__version__ = "12.0.2"
-__doc__ = get_pypi_slogan()  # pylint: disable=redefined-builtin
+__version__ = "12.0.3"
+__doc__ = get_short_slogan()  # pylint: disable=redefined-builtin
