@@ -1,14 +1,16 @@
 # --------------------------------------------------------------------------------------------------
 # Copyright (c) Lukas Vik. All rights reserved.
 #
-# This file is part of the tsfpga project.
+# This file is part of the tsfpga project, a project platform for modern FPGA development.
 # https://tsfpga.com
 # https://gitlab.com/tsfpga/tsfpga
 # --------------------------------------------------------------------------------------------------
 
+# Standard libraries
 import re
 from pathlib import Path
 
+# Third party libraries
 from git import Repo
 
 
@@ -26,12 +28,12 @@ class GitSimulationSubset:
         Arguments:
             repo_root (pathlib.Path): Root directory where git commands will be run.
             reference_branch (str): What git branch to compare against, when finding what files have
-                changed. Typically "origin/master".
+                changed. Typically "origin/main" or "origin/master".
             vunit_proj: A vunit project with all source files and testbenches added. Will be used
                 for dependency scanning.
             vunit_preprocessed_path (pathlib.Path): If location/check preprocessing is enabled
                 in your VUnit project, supply the path to vunit_out/preprocessed.
-            modules (.ModuleList): A list of modules that are included in the VUnit project. Must be
+            modules (ModuleList): A list of modules that are included in the VUnit project. Must be
                 supplied only if preprocessing is enabled.
         """
         self._repo_root = repo_root
@@ -108,7 +110,7 @@ class GitSimulationSubset:
                 # later commit. Include only files that are currently existing.
                 if b_path.exists():
                     if b_path.name.endswith(".vhd"):
-                        files.add(b_path)
+                        files.add(b_path.resolve())
 
         self._print_file_list("Found git diff in the following files", files)
         return files
