@@ -1,11 +1,12 @@
 # --------------------------------------------------------------------------------------------------
 # Copyright (c) Lukas Vik. All rights reserved.
 #
-# This file is part of the tsfpga project.
+# This file is part of the tsfpga project, a project platform for modern FPGA development.
 # https://tsfpga.com
 # https://gitlab.com/tsfpga/tsfpga
 # --------------------------------------------------------------------------------------------------
 
+# Local folder libraries
 from .simlib_commercial import VivadoSimlibCommercial
 from .simlib_ghdl import VivadoSimlibGhdl
 
@@ -26,7 +27,7 @@ class VivadoSimlib:
             output_path (pathlib.Path): The compiled simlib will be placed here.
             vunit_proj: The VUnit project that is used to run simulation.
             vivado_path (pathlib.Path): Path to Vivado executable. If left out, the default
-                from PATH will be used.
+                from system ``PATH`` will be used.
         Return:
             A :class:`.VivadoSimlibCommon` child object.
         """
