@@ -1,13 +1,17 @@
 # --------------------------------------------------------------------------------------------------
 # Copyright (c) Lukas Vik. All rights reserved.
 #
-# This file is part of the tsfpga project.
+# This file is part of the tsfpga project, a project platform for modern FPGA development.
 # https://tsfpga.com
 # https://gitlab.com/tsfpga/tsfpga
 # --------------------------------------------------------------------------------------------------
 
+# First party libraries
 from tsfpga.system_utils import create_file
+
+# Local folder libraries
 from .common import to_tcl_path
+from .generics import get_vivado_tcl_generic_value
 
 
 class VivadoTcl:
@@ -238,11 +242,8 @@ class VivadoTcl:
 
         generic_list = []
         for name, value in generics.items():
-            if isinstance(value, bool):
-                value_tcl_formatted = "1'b1" if value else "1'b0"
-                generic_list.append(f"{name}={value_tcl_formatted}")
-            else:
-                generic_list.append(f"{name}={value}")
+            value_tcl_formatted = get_vivado_tcl_generic_value(value=value)
+            generic_list.append(f"{name}={value_tcl_formatted}")
 
         generics_string = " ".join(generic_list)
         return f"set_property generic {{{generics_string}}} [current_fileset]\n"
@@ -285,29 +286,35 @@ class VivadoTcl:
         run_index,
         generics=None,
         synth_only=False,
+        from_impl=False,
         analyze_synthesis_timing=True,
     ):
         # Max value in Vivado 2018.3+. set_param will give an error if higher number.
         num_threads_general = min(num_threads, 32)
         num_threads_synth = min(num_threads, 8)
 
-        synth_run = f"synth_{run_index}"
-        impl_run = f"impl_{run_index}"
-
         tcl = f"open_project {to_tcl_path(project_file)}\n"
         tcl += f"set_param general.maxThreads {num_threads_general}\n"
         tcl += f"set_param synth.maxThreads {num_threads_synth}\n"
         tcl += "\n"
         tcl += self._add_generics(generics)
         tcl += "\n"
-        tcl += self._synthesis(synth_run, num_threads, analyze_synthesis_timing)
-        tcl += "\n"
-        if not synth_only:
-            tcl += self._run(impl_run, num_threads, to_step="write_bitstream")
+
+        if not from_impl:
+            synth_run = f"synth_{run_index}"
+
+            tcl += self._synthesis(synth_run, num_threads, analyze_synthesis_timing)
             tcl += "\n"
+
+        if not synth_only:
+            impl_run = f"impl_{run_index}"
+
+            tcl += self._run(impl_run, num_threads, to_step="write_bitstream")
             tcl += self._write_hw_platform(output_path)
             tcl += "\n"
+
         tcl += "exit\n"
+
         return tcl
 
     def _synthesis(self, run, num_threads, analyze_synthesis_timing):
@@ -370,6 +377,30 @@ if {[get_property PROGRESS [get_runs ${run}]] != "100%"} {
         return tcl
 
     def _write_hw_platform(self, output_path):
-        xsa_file = to_tcl_path(output_path / (self.name + ".xsa"))
-        tcl = f"write_hw_platform -fixed -force {{{xsa_file}}}\n"
+        """
+        TCL command to create a "hardware platform" .xsa file (aka, "hdf" or "hwdef" file).
+
+        This is mainly used for Zynq devices to generate code to set up the PS at boot.
+        There is also code generated for each MicroBlaze that is present in the design.
+        If there is neither a block design nor a MicroBlaze available, the .xsa will be empty apart
+        from some info about which part is used, etc.
+
+        The '-quiet' flag is used since there was a Vivado bug observed in this very
+        specific scenario:
+        * Vivado 2022.1
+        * UltraScale+ non-Zynq device (i.e. no block design)
+        * Design contains MicroBlaze
+        * Design contains ILA
+        In this case the 'write_hw_platform' call would fail.
+        This bug might be present in other Vivado versions and in other scenarios as well.
+        Since this is a very fringe scenario, and it is unlikely that anyone would ever need the
+        .xsa file specifically from the ILA build, we allow the command to fail quietly.
+        """
+        xsa_file = to_tcl_path(output_path / f"{self.name}.xsa")
+
+        tcl = f"""
+puts "Creating hardware platform {xsa_file}..."
+write_hw_platform -fixed -force -quiet {{{xsa_file}}}
+"""
+
         return tcl
